@@ -210,6 +210,15 @@
 #' # Add sum tiles
 #' plot_confusion_matrix(evaluation, add_sums = TRUE)
 #'
+#' # Add labels to diagonal row and column percentages
+#' # This example assumes "B" is the positive class
+#' # but you could write anything as prefix to the percentages
+#' plot_confusion_matrix(
+#'     evaluation,
+#'     font_row_percentages = font(prefix=c("NPV = ", "", "", "PPV = ")),
+#'     font_col_percentages = font(prefix=c("Spec = ", "", "", "Sens = "))
+#' )
+#'
 #' # Three (or more) classes
 #'
 #' # Create targets and predictions data frame
@@ -735,7 +744,7 @@ plot_confusion_matrix <- function(conf_matrix,
 
     # Set total counts tile text
     sum_data[nrow(sum_data), "N_text"] <- ifelse(
-      isTRUE(counts_on_top),
+      isTRUE(counts_on_top) || !isTRUE(add_normalized),
       as.character(sum_data[nrow(sum_data), "N"]),
       ""
     )
